@@ -1,6 +1,6 @@
 /*
- *      Copyright (C) 2004, 2006, 2007, 2008 Free Software Foundation
- *      Copyright (C) 2000,2001 Fabio Fiorina
+ * Copyright (C) 2004, 2006, 2007, 2008, 2009 Free Software Foundation
+ * Copyright (C) 2000,2001 Fabio Fiorina
  *
  * This file is part of LIBTASN1.
  *
@@ -21,7 +21,6 @@
  */
 
 #include <int.h>
-#include <errors.h>
 #include "parser_aux.h"
 #include "gstr.h"
 #include "structure.h"
@@ -198,14 +197,15 @@ asn1_find_node (ASN1_TYPE pointer, const char *name)
 /*   len: character number of value.                              */
 /* Return: pointer to the NODE_ASN element.                       */
 /******************************************************************/
-ASN1_TYPE 
-_asn1_set_value (ASN1_TYPE  node, const void *value, unsigned int len)
+ASN1_TYPE
+_asn1_set_value (ASN1_TYPE node, const void *value, unsigned int len)
 {
   if (node == NULL)
     return node;
   if (node->value)
     {
-      _asn1_free (node->value);
+      if (node->value != node->small_value)
+	_asn1_free (node->value);
       node->value = NULL;
       node->value_len = 0;
     }
@@ -213,9 +213,16 @@ _asn1_set_value (ASN1_TYPE  node, const void *value, unsigned int len)
   if (!len)
     return node;
 
-  node->value = (unsigned char *) _asn1_malloc (len);
-  if (node->value == NULL)
-    return NULL;
+  if (len < sizeof (node->small_value))
+    {
+      node->value = node->small_value;
+    }
+  else
+    {
+      node->value = _asn1_malloc (len);
+      if (node->value == NULL)
+	return NULL;
+    }
   node->value_len = len;
 
   memcpy (node->value, value, len);
@@ -226,18 +233,18 @@ _asn1_set_value (ASN1_TYPE  node, const void *value, unsigned int len)
 /* Function : _asn1_set_value_octet                               */
 /* Description: sets the field VALUE in a NODE_ASN element. The   */
 /*              previous value (if exist) will be lost. The value */
-/* 		given is stored as an octet string.               */
+/*		given is stored as an octet string.               */
 /* Parameters:                                                    */
 /*   node: element pointer.                                       */
 /*   value: pointer to the value that you want to set.            */
 /*   len: character number of value.                              */
 /* Return: pointer to the NODE_ASN element.                       */
 /******************************************************************/
-ASN1_TYPE 
-_asn1_set_value_octet (ASN1_TYPE  node, const void *value, unsigned int len)
+ASN1_TYPE
+_asn1_set_value_octet (ASN1_TYPE node, const void *value, unsigned int len)
 {
-int len2;
-void* temp;
+  int len2;
+  void *temp;
 
   if (node == NULL)
     return node;
@@ -254,15 +261,16 @@ void* temp;
 /* the same as _asn1_set_value except that it sets an already malloc'ed
  * value.
  */
-ASN1_TYPE 
-_asn1_set_value_m (ASN1_TYPE  node, void *value, unsigned int len)
+ASN1_TYPE
+_asn1_set_value_m (ASN1_TYPE node, void *value, unsigned int len)
 {
   if (node == NULL)
     return node;
 
   if (node->value)
     {
-      _asn1_free (node->value);
+      if (node->value != node->small_value)
+	_asn1_free (node->value);
       node->value = NULL;
       node->value_len = 0;
     }
@@ -279,33 +287,51 @@ _asn1_set_value_m (ASN1_TYPE  node, void *value, unsigned int len)
 /******************************************************************/
 /* Function : _asn1_append_value                                  */
 /* Description: appends to the field VALUE in a NODE_ASN element. */
-/*              					          */
+/*							          */
 /* Parameters:                                                    */
 /*   node: element pointer.                                       */
 /*   value: pointer to the value that you want to be appended.    */
 /*   len: character number of value.                              */
 /* Return: pointer to the NODE_ASN element.                       */
 /******************************************************************/
-ASN1_TYPE 
-_asn1_append_value (ASN1_TYPE  node, const void *value, unsigned int len)
+ASN1_TYPE
+_asn1_append_value (ASN1_TYPE node, const void *value, unsigned int len)
 {
   if (node == NULL)
     return node;
-  if (node->value != NULL) /* value is allocated */
+  if (node->value != NULL && node->value != node->small_value)
     {
+      /* value is allocated */
       int prev_len = node->value_len;
-      node->value_len+=len;
-      node->value = _asn1_realloc( node->value, node->value_len);
-      if (node->value == NULL) {
-	node->value_len = 0;
-	return NULL;
-      }
-      memcpy( &node->value[prev_len], value, len);
+      node->value_len += len;
+      node->value = _asn1_realloc (node->value, node->value_len);
+      if (node->value == NULL)
+	{
+	  node->value_len = 0;
+	  return NULL;
+	}
+      memcpy (&node->value[prev_len], value, len);
 
       return node;
     }
-  else /* node->value == NULL */
-    return _asn1_set_value(node, value, len);
+  else if (node->value == node->small_value)
+    {
+      /* value is in node */
+      int prev_len = node->value_len;
+      node->value_len += len;
+      node->value = _asn1_malloc (node->value_len);
+      if (node->value == NULL)
+	{
+	  node->value_len = 0;
+	  return NULL;
+	}
+      memcpy (node->value, node->small_value, prev_len);
+      memcpy (&node->value[prev_len], value, len);
+
+      return node;
+    }
+  else				/* node->value == NULL */
+    return _asn1_set_value (node, value, len);
 }
 
 /******************************************************************/
@@ -318,8 +344,8 @@ _asn1_append_value (ASN1_TYPE  node, const void *value, unsigned int len)
 /*         to set.                                                */
 /* Return: pointer to the NODE_ASN element.                       */
 /******************************************************************/
-ASN1_TYPE 
-_asn1_set_name (ASN1_TYPE  node, const char *name)
+ASN1_TYPE
+_asn1_set_name (ASN1_TYPE node, const char *name)
 {
   if (node == NULL)
     return node;
@@ -353,8 +379,8 @@ _asn1_set_name (ASN1_TYPE  node, const char *name)
 /*          by NODE.                                              */
 /* Return: pointer to *NODE.                                      */
 /******************************************************************/
-ASN1_TYPE 
-_asn1_set_right (ASN1_TYPE  node, ASN1_TYPE  right)
+ASN1_TYPE
+_asn1_set_right (ASN1_TYPE node, ASN1_TYPE right)
 {
   if (node == NULL)
     return node;
@@ -372,8 +398,8 @@ _asn1_set_right (ASN1_TYPE  node, ASN1_TYPE  right)
 /*   node: NODE_ASN element pointer.                              */
 /* Return: field RIGHT of NODE.                                   */
 /******************************************************************/
-ASN1_TYPE 
-_asn1_get_right (ASN1_TYPE  node)
+ASN1_TYPE
+_asn1_get_right (ASN1_TYPE node)
 {
   if (node == NULL)
     return NULL;
@@ -387,8 +413,8 @@ _asn1_get_right (ASN1_TYPE  node)
 /*   node: starting element pointer.                              */
 /* Return: pointer to the last element along the right chain.     */
 /******************************************************************/
-ASN1_TYPE 
-_asn1_get_last_right (ASN1_TYPE  node)
+ASN1_TYPE
+_asn1_get_last_right (ASN1_TYPE node)
 {
   ASN1_TYPE p;
 
@@ -409,8 +435,8 @@ _asn1_get_last_right (ASN1_TYPE  node)
 /*          by NODE.                                              */
 /* Return: pointer to *NODE.                                      */
 /******************************************************************/
-ASN1_TYPE 
-_asn1_set_down (ASN1_TYPE  node, ASN1_TYPE  down)
+ASN1_TYPE
+_asn1_set_down (ASN1_TYPE node, ASN1_TYPE down)
 {
   if (node == NULL)
     return node;
@@ -428,8 +454,8 @@ _asn1_set_down (ASN1_TYPE  node, ASN1_TYPE  down)
 /*   node: NODE_ASN element pointer.                              */
 /* Return: field DOWN of NODE.                                    */
 /******************************************************************/
-ASN1_TYPE 
-_asn1_get_down (ASN1_TYPE  node)
+ASN1_TYPE
+_asn1_get_down (ASN1_TYPE node)
 {
   if (node == NULL)
     return NULL;
@@ -444,7 +470,7 @@ _asn1_get_down (ASN1_TYPE  node)
 /* Return: a null terminated string.                              */
 /******************************************************************/
 char *
-_asn1_get_name (ASN1_TYPE  node)
+_asn1_get_name (ASN1_TYPE node)
 {
   if (node == NULL)
     return NULL;
@@ -462,8 +488,8 @@ _asn1_get_name (ASN1_TYPE  node)
 /*          value of field TYPE.                                  */
 /* Return: NODE pointer.                                          */
 /******************************************************************/
-ASN1_TYPE 
-_asn1_mod_type (ASN1_TYPE  node, unsigned int value)
+ASN1_TYPE
+_asn1_mod_type (ASN1_TYPE node, unsigned int value)
 {
   if (node == NULL)
     return node;
@@ -480,14 +506,14 @@ _asn1_mod_type (ASN1_TYPE  node, unsigned int value)
 /*   node: NODE_ASN element pointer.                              */
 /******************************************************************/
 void
-_asn1_remove_node (ASN1_TYPE  node)
+_asn1_remove_node (ASN1_TYPE node)
 {
   if (node == NULL)
     return;
 
   if (node->name != NULL)
     _asn1_free (node->name);
-  if (node->value != NULL)
+  if (node->value != NULL && node->value != node->small_value)
     _asn1_free (node->value);
   _asn1_free (node);
 }
@@ -499,8 +525,8 @@ _asn1_remove_node (ASN1_TYPE  node)
 /*   node: NODE_ASN element pointer.                              */
 /* Return: Null if not found.                                     */
 /******************************************************************/
-ASN1_TYPE 
-_asn1_find_up (ASN1_TYPE  node)
+ASN1_TYPE
+_asn1_find_up (ASN1_TYPE node)
 {
   ASN1_TYPE p;
 
